==> vue-dialog-select-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-select/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import DialogBox from '@opentinyvue/vue-dialog-box';
import Button from '@opentinyvue/vue-button';
import Pager from '@opentinyvue/vue-pager';
import Grid from '@opentinyvue/vue-grid';
import Split from '@opentinyvue/vue-split';
import SelectedBox from '@opentinyvue/vue-selected-box';
import Input from '@opentinyvue/vue-input';
import Tree from '@opentinyvue/vue-tree';
import { iconSearch } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/dialog-select/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: [
    "open",
    "close",
    "opened",
    "closed",
    "drag-start",
    "drag-end",
    "drag-move",
    "update:visible",
    "size-change",
    "current-change",
    "prev-click",
    "next-click",
    "before-page-change",
    "change",
    // tiny 新增
    "resize",
    "clear",
    "delete"
  ],
  props: [].concat(props, ["dialogOp", "visible", "popseletor", "multi", "gridOp", "textField", "textSplit", "valueField", "valueSplit", "remoteSearch", "showPager", "pagerOp", "showSelectedBox", "selectedBoxOp", "treeOp", "beforeClose", "autoLookup", "lookupMethod", "mainHeight"]),
  components: {
    TinyDialogBox: DialogBox,
    TinyButton: Button,
    TinyPager: Pager,
    TinyGrid: Grid,
    TinySplit: Split,
    TinySelectedBox: SelectedBox,
    TinyInput: Input,
    TinyTree: Tree,
    TinyIconSearch: iconSearch()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-dialog-box", _vm._b({
    class: ["tiny-dialog-select", {
      "radio-check": !_vm.multi
    }, {
      "is-grid": _vm.popseletor === "grid"
    }, {
      "is-tree": _vm.popseletor === "tree"
    }],
    attrs: {
      "visible": _vm.visible,
      "modal": "",
      "draggable": "",
      "append-to-body": "",
      "modal-append-to-body": "",
      "close-on-press-escape": false,
      "close-on-click-modal": false
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:visible", $event);
      },
      "open": function open($event) {
        return _vm.$emit("open", $event);
      },
      "close": function close($event) {
        return _vm.$emit("close", $event);
      },
      "opened": function opened($event) {
        return _vm.$emit("opened", $event);
      },
      "closed": function closed($event) {
        return _vm.$emit("closed", $event);
      },
      "drag-start": function dragStart($event) {
        return _vm.$emit("drag-start", $event);
      },
      "drag-end": function dragEnd($event) {
        return _vm.$emit("drag-end", $event);
      },
      "drag-move": function dragMove($event) {
        return _vm.$emit("drag-move", $event);
      },
      "resize": function resize($event) {
        return _vm.$emit("resize", $event);
      }
    },
    scopedSlots: _vm._u([_vm.slots.title ? {
      key: "title",
      fn: function fn(params) {
        return [_vm._t("title", null, null, params)];
      }
    } : null, {
      key: "footer",
      fn: function fn(params) {
        return [_vm._t("footer", function() {
          return [_c("div", {
            staticClass: "tiny-dialog-select__footer"
          }, [_c("div", {
            staticClass: "tiny-dialog-select__footer-pager"
          }, [_vm.popseletor === "grid" && _vm.showPager ? _c("tiny-pager", _vm._b({
            ref: "pager",
            attrs: {
              "pager-count": 7
            },
            on: {
              "size-change": function sizeChange($event) {
                return _vm.$emit("size-change", $event);
              },
              "current-change": function currentChange($event) {
                return _vm.$emit("current-change", $event);
              },
              "prev-click": function prevClick($event) {
                return _vm.$emit("prev-click", $event);
              },
              "next-click": function nextClick($event) {
                return _vm.$emit("next-click", $event);
              },
              "before-page-change": function beforePageChange($event) {
                return _vm.$emit("before-page-change", $event);
              }
            }
          }, "tiny-pager", _vm.pagerOp, false)) : _vm._e()], 1), _c("div", {
            staticClass: "tiny-dialog-select__footer-buttons"
          }, [_vm._t("footer-buttons", function() {
            return [_c("tiny-button", {
              on: {
                "click": _vm.onFooterCancel
              }
            }, [_vm._v(_vm._s(_vm.t("ui.button.cancel")))]), _c("tiny-button", {
              attrs: {
                "type": "primary"
              },
              on: {
                "click": _vm.onFooterConfirm
              }
            }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])];
          }, {
            "cancel": _vm.onFooterCancel,
            "confirm": _vm.onFooterConfirm
          })], 2)])];
        }, {
          "cancel": _vm.onFooterCancel,
          "confirm": _vm.onFooterConfirm
        }, params)];
      }
    }], null, true)
  }, "tiny-dialog-box", _vm.dialogOp, false), [_c("div", {
    staticClass: "tiny-dialog-select__body"
  }, [_vm.popseletor === "grid" && _vm.slots.search ? _c("div", {
    staticClass: "tiny-dialog-select__body-search"
  }, [_vm._t("search")], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-dialog-select__body-selector"
  }, [_c("tiny-split", {
    style: "height:" + _vm.mainHeight + "px",
    attrs: {
      "trigger-simple": "",
      "disabled": !_vm.multi
    },
    scopedSlots: _vm._u([{
      key: "left",
      fn: function fn() {
        return [_vm.popseletor === "grid" ? _c("div", {
          staticClass: "tiny-dialog-select__body-grid",
          style: "height:" + _vm.mainHeight + "px"
        }, [_vm.visible || _vm.state.multiGridStore.inited ? _c("tiny-grid", _vm._b({
          ref: "multiGrid",
          attrs: {
            "border": _vm.state.isBorder,
            "stripe": false,
            "auto-resize": "",
            "height": _vm.mainHeight + "px",
            "loading": _vm.state.multiGridStore.loading,
            "row-id": _vm.valueField,
            "columns": _vm.state.gridColumns,
            "select-config": _vm.state.multiGridStore.selectConfig,
            "radio-config": _vm.state.multiGridStore.radioConfig
          },
          on: {
            "select-all": _vm.multiGridSelectAll,
            "select-change": _vm.multiGridSelectChange,
            "radio-change": _vm.multiGridRadioChange
          }
        }, "tiny-grid", _vm.gridOp, false)) : _vm._e()], 1) : _vm._e(), _vm.popseletor === "tree" ? _c("div", {
          staticClass: "tiny-dialog-select__body-tree",
          style: "height:" + _vm.mainHeight + "px"
        }, [_c("tiny-input", {
          attrs: {
            "placeholder": _vm.t("ui.dialogSelect.treeSearch"),
            "clearable": ""
          },
          on: {
            "change": _vm.doMultiTreeFilter
          },
          scopedSlots: _vm._u([_vm.state.theme !== "saas" ? {
            key: "prefix",
            fn: function fn2() {
              return [_c("tiny-icon-search")];
            },
            proxy: true
          } : null], null, true),
          model: {
            value: _vm.state.multiTreeStore.filterText,
            callback: function callback($$v) {
              _vm.$set(_vm.state.multiTreeStore, "filterText", $$v);
            },
            expression: "state.multiTreeStore.filterText"
          }
        }), _c("div", {
          staticClass: "tiny-dialog-select__body-tree-wrapper",
          style: {
            height: "calc(100% - " + _vm.state.constants.INPUT_HEIGHT + " - " + _vm.state.constants.INPUT_MARGIN_BOTTOM + " )"
          }
        }, [_c("div", [_vm.visible || _vm.state.multiTreeStore.inited ? _c("tiny-tree", _vm._b({
          ref: "multiTree",
          attrs: {
            "show-checkbox": _vm.multi,
            "show-radio": !_vm.multi,
            "lazy-current": "",
            "lazy": "",
            "after-load": _vm.multiTreeAfterLoad,
            "view-type": _vm.state.multiTreeStore.viewType,
            "default-expanded-keys": _vm.state.multiTreeStore.expandedKeys,
            "default-expanded-keys-highlight": _vm.state.multiTreeStore.highlight,
            "filter-node-method": _vm.multiTreeFilterNode,
            "filter-plain-method": _vm.multiTreeFilterPlain,
            "default-checked-keys": _vm.state.multiTreeStore.checkedKeys
          },
          on: {
            "leave-plain-view": _vm.multiTreeLeavePlain,
            "check": _vm.multiTreeCheck,
            "node-expand": _vm.multiTreeCheck,
            "node-collapse": _vm.multiTreeCheck,
            "check-plain": _vm.multiTreeCheck,
            "check-change": _vm.multiTreeRadio
          }
        }, "tiny-tree", _vm.treeOp, false)) : _vm._e()], 1)])], 1) : _vm._e()];
      },
      proxy: true
    }, {
      key: "right",
      fn: function fn() {
        return [_vm.multi ? _c("div", {
          staticClass: "tiny-dialog-select__body-box",
          style: "height:" + _vm.mainHeight + "px"
        }, [_vm.showSelectedBox ? _c("tiny-selected-box", _vm._b({
          ref: "selectedBox",
          attrs: {
            "select": _vm.state.selectedDatas
          },
          on: {
            "clear": _vm.selectedBoxClear,
            "delete": _vm.selectedBoxDelete,
            "drag": _vm.selectedBoxDrag
          },
          scopedSlots: _vm._u([_vm.slots.select ? {
            key: "select",
            fn: function fn2(params) {
              return [_vm._t("select", null, null, params)];
            }
          } : null, _vm.slots.button ? {
            key: "button",
            fn: function fn2(params) {
              return [_vm._t("button", null, null, params)];
            }
          } : null, _vm.slots.clear ? {
            key: "clear",
            fn: function fn2(params) {
              return [_vm._t("clear", null, null, params)];
            }
          } : null, _vm.slots.option ? {
            key: "option",
            fn: function fn2(params) {
              return [_vm._t("option", null, null, params)];
            }
          } : null, _vm.slots.close ? {
            key: "close",
            fn: function fn2(params) {
              return [_vm._t("close", null, null, params)];
            }
          } : null], null, true)
        }, "tiny-selected-box", _vm.selectedBoxOp, false)) : _vm._e()], 1) : _vm._e()];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.splitValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "splitValue", $$v);
      },
      expression: "state.splitValue"
    }
  })], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-dialog-select-2.24.1.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-select/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import DialogBox from '@opentinyvue/vue-dialog-box';
import Button from '@opentinyvue/vue-button';
import Pager from '@opentinyvue/vue-pager';
import Grid from '@opentinyvue/vue-grid';
import Split from '@opentinyvue/vue-split';
import SelectedBox from '@opentinyvue/vue-selected-box';
import Input from '@opentinyvue/vue-input';
import Tree from '@opentinyvue/vue-tree';
import { iconSearch } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/dialog-select/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: [
    "open",
    "close",
    "opened",
    "closed",
    "drag-start",
    "drag-end",
    "drag-move",
    "update:visible",
    "size-change",
    "current-change",
    "prev-click",
    "next-click",
    "before-page-change",
    "change",
    // tiny 新增
    "resize",
    "clear",
    "delete"
  ],
  props: [].concat(props, ["dialogOp", "visible", "popseletor", "multi", "gridOp", "textField", "textSplit", "valueField", "valueSplit", "remoteSearch", "showPager", "pagerOp", "showSelectedBox", "selectedBoxOp", "treeOp", "beforeClose", "autoLookup", "lookupMethod", "mainHeight", "lockScroll"]),
  components: {
    TinyDialogBox: DialogBox,
    TinyButton: Button,
    TinyPager: Pager,
    TinyGrid: Grid,
    TinySplit: Split,
    TinySelectedBox: SelectedBox,
    TinyInput: Input,
    TinyTree: Tree,
    TinyIconSearch: iconSearch()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-dialog-box", _vm._b({
    class: ["tiny-dialog-select", {
      "radio-check": !_vm.multi
    }, {
      "is-grid": _vm.popseletor === "grid"
    }, {
      "is-tree": _vm.popseletor === "tree"
    }],
    attrs: {
      "visible": _vm.visible,
      "modal": "",
      "draggable": "",
      "append-to-body": "",
      "modal-append-to-body": "",
      "close-on-press-escape": false,
      "close-on-click-modal": false,
      "lock-scroll": _vm.lockScroll
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:visible", $event);
      },
      "open": function open($event) {
        return _vm.$emit("open", $event);
      },
      "close": function close($event) {
        return _vm.$emit("close", $event);
      },
      "opened": function opened($event) {
        return _vm.$emit("opened", $event);
      },
      "closed": function closed($event) {
        return _vm.$emit("closed", $event);
      },
      "drag-start": function dragStart($event) {
        return _vm.$emit("drag-start", $event);
      },
      "drag-end": function dragEnd($event) {
        return _vm.$emit("drag-end", $event);
      },
      "drag-move": function dragMove($event) {
        return _vm.$emit("drag-move", $event);
      },
      "resize": function resize($event) {
        return _vm.$emit("resize", $event);
      }
    },
    scopedSlots: _vm._u([_vm.slots.title ? {
      key: "title",
      fn: function fn(params) {
        return [_vm._t("title", null, null, params)];
      }
    } : null, {
      key: "footer",
      fn: function fn(params) {
        return [_vm._t("footer", function() {
          return [_c("div", {
            staticClass: "tiny-dialog-select__footer"
          }, [_c("div", {
            staticClass: "tiny-dialog-select__footer-pager"
          }, [_vm.popseletor === "grid" && _vm.showPager ? _c("tiny-pager", _vm._b({
            ref: "pager",
            attrs: {
              "pager-count": 7
            },
            on: {
              "size-change": function sizeChange($event) {
                return _vm.$emit("size-change", $event);
              },
              "current-change": function currentChange($event) {
                return _vm.$emit("current-change", $event);
              },
              "prev-click": function prevClick($event) {
                return _vm.$emit("prev-click", $event);
              },
              "next-click": function nextClick($event) {
                return _vm.$emit("next-click", $event);
              },
              "before-page-change": function beforePageChange($event) {
                return _vm.$emit("before-page-change", $event);
              }
            }
          }, "tiny-pager", _vm.pagerOp, false)) : _vm._e()], 1), _c("div", {
            staticClass: "tiny-dialog-select__footer-buttons"
          }, [_vm._t("footer-buttons", function() {
            return [_c("tiny-button", {
              on: {
                "click": _vm.onFooterCancel
              }
            }, [_vm._v(_vm._s(_vm.t("ui.button.cancel")))]), _c("tiny-button", {
              attrs: {
                "type": "primary"
              },
              on: {
                "click": _vm.onFooterConfirm
              }
            }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])];
          }, {
            "cancel": _vm.onFooterCancel,
            "confirm": _vm.onFooterConfirm
          })], 2)])];
        }, {
          "cancel": _vm.onFooterCancel,
          "confirm": _vm.onFooterConfirm
        }, params)];
      }
    }], null, true)
  }, "tiny-dialog-box", _vm.dialogOp, false), [_c("div", {
    staticClass: "tiny-dialog-select__body"
  }, [_vm.popseletor === "grid" && _vm.slots.search ? _c("div", {
    staticClass: "tiny-dialog-select__body-search"
  }, [_vm._t("search")], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-dialog-select__body-selector"
  }, [_c("tiny-split", {
    style: "height:" + _vm.mainHeight + "px",
    attrs: {
      "trigger-simple": "",
      "disabled": !_vm.multi
    },
    scopedSlots: _vm._u([{
      key: "left",
      fn: function fn() {
        return [_vm.popseletor === "grid" ? _c("div", {
          staticClass: "tiny-dialog-select__body-grid",
          style: "height:" + _vm.mainHeight + "px"
        }, [_vm.visible || _vm.state.multiGridStore.inited ? _c("tiny-grid", _vm._b({
          ref: "multiGrid",
          attrs: {
            "border": _vm.state.isBorder,
            "stripe": false,
            "auto-resize": "",
            "height": _vm.mainHeight + "px",
            "loading": _vm.state.multiGridStore.loading,
            "row-id": _vm.valueField,
            "columns": _vm.state.gridColumns,
            "select-config": _vm.state.multiGridStore.selectConfig,
            "radio-config": _vm.state.multiGridStore.radioConfig
          },
          on: {
            "select-all": _vm.multiGridSelectAll,
            "select-change": _vm.multiGridSelectChange,
            "radio-change": _vm.multiGridRadioChange
          }
        }, "tiny-grid", _vm.gridOp, false)) : _vm._e()], 1) : _vm._e(), _vm.popseletor === "tree" ? _c("div", {
          staticClass: "tiny-dialog-select__body-tree",
          style: "height:" + _vm.mainHeight + "px"
        }, [_c("tiny-input", {
          attrs: {
            "placeholder": _vm.t("ui.dialogSelect.treeSearch"),
            "clearable": ""
          },
          on: {
            "change": _vm.doMultiTreeFilter
          },
          scopedSlots: _vm._u([_vm.state.theme !== "saas" ? {
            key: "prefix",
            fn: function fn2() {
              return [_c("tiny-icon-search")];
            },
            proxy: true
          } : null], null, true),
          model: {
            value: _vm.state.multiTreeStore.filterText,
            callback: function callback($$v) {
              _vm.$set(_vm.state.multiTreeStore, "filterText", $$v);
            },
            expression: "state.multiTreeStore.filterText"
          }
        }), _c("div", {
          staticClass: "tiny-dialog-select__body-tree-wrapper",
          style: {
            height: "calc(100% - " + _vm.state.constants.INPUT_HEIGHT + " - " + _vm.state.constants.INPUT_MARGIN_BOTTOM + " )"
          }
        }, [_c("div", [_vm.visible || _vm.state.multiTreeStore.inited ? _c("tiny-tree", _vm._b({
          ref: "multiTree",
          attrs: {
            "show-checkbox": _vm.multi,
            "show-radio": !_vm.multi,
            "lazy-current": "",
            "lazy": "",
            "after-load": _vm.multiTreeAfterLoad,
            "view-type": _vm.state.multiTreeStore.viewType,
            "default-expanded-keys": _vm.state.multiTreeStore.expandedKeys,
            "default-expanded-keys-highlight": _vm.state.multiTreeStore.highlight,
            "filter-node-method": _vm.multiTreeFilterNode,
            "filter-plain-method": _vm.multiTreeFilterPlain,
            "default-checked-keys": _vm.state.multiTreeStore.checkedKeys
          },
          on: {
            "leave-plain-view": _vm.multiTreeLeavePlain,
            "check": _vm.multiTreeCheck,
            "node-expand": _vm.multiTreeCheck,
            "node-collapse": _vm.multiTreeCheck,
            "check-plain": _vm.multiTreeCheck,
            "check-change": _vm.multiTreeRadio
          }
        }, "tiny-tree", _vm.treeOp, false)) : _vm._e()], 1)])], 1) : _vm._e()];
      },
      proxy: true
    }, {
      key: "right",
      fn: function fn() {
        return [_vm.multi ? _c("div", {
          staticClass: "tiny-dialog-select__body-box",
          style: "height:" + _vm.mainHeight + "px"
        }, [_vm.showSelectedBox ? _c("tiny-selected-box", _vm._b({
          ref: "selectedBox",
          attrs: {
            "select": _vm.state.selectedDatas
          },
          on: {
            "clear": _vm.selectedBoxClear,
            "delete": _vm.selectedBoxDelete,
            "drag": _vm.selectedBoxDrag
          },
          scopedSlots: _vm._u([_vm.slots.select ? {
            key: "select",
            fn: function fn2(params) {
              return [_vm._t("select", null, null, params)];
            }
          } : null, _vm.slots.button ? {
            key: "button",
            fn: function fn2(params) {
              return [_vm._t("button", null, null, params)];
            }
          } : null, _vm.slots.clear ? {
            key: "clear",
            fn: function fn2(params) {
              return [_vm._t("clear", null, null, params)];
            }
          } : null, _vm.slots.option ? {
            key: "option",
            fn: function fn2(params) {
              return [_vm._t("option", null, null, params)];
            }
          } : null, _vm.slots.close ? {
            key: "close",
            fn: function fn2(params) {
              return [_vm._t("close", null, null, params)];
            }
          } : null], null, true)
        }, "tiny-selected-box", _vm.selectedBoxOp, false)) : _vm._e()], 1) : _vm._e()];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.splitValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "splitValue", $$v);
      },
      expression: "state.splitValue"
    }
  })], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
